/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common.downloadtoken;

import static org.springframework.hateoas.server.mvc.WebMvcLinkBuilder.*;

import java.net.URI;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import de.ozgcloud.alfa.common.binaryfile.FileId;

@RestController
@RequestMapping(DownloadTokenController.DOWNLOAD_TOKEN_PATH)
public class DownloadTokenController {

	public static final String DOWNLOAD_TOKEN_PATH = "/api/downloadtoken"; // NOSONAR

	public static final String PARAM_TOKEN = "token";

	@Autowired
	private DownloadTokenService tokenService;

	@PostMapping
	public ResponseEntity<Void> downloadToken(@RequestBody DownloadTokenRequest request) {
		return ResponseEntity.created(buildUri(request.getFileId())).build();
	}

	private URI buildUri(FileId fileId) {
		return linkTo(DownloadTokenController.class).toUriComponentsBuilder().queryParam(PARAM_TOKEN, tokenService.createToken(fileId))
				.build()
				.toUri();
	}

	@GetMapping
	public ResponseEntity<DownloadTokenResponse> getToken(@RequestParam String token) {
		return ResponseEntity.ok(DownloadTokenResponse.builder().token(token).build());
	}
}