/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.postfach;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import de.ozgcloud.alfa.common.command.CommandBody;
import de.ozgcloud.alfa.vorgang.VorgangWithEingang;

@Component
class PostfachNachrichtHelper {

	static final String SERVICEKONTO_TYPE_FIELD = "serviceKontoType";

	@Autowired
	private PostfachMailMapper mapper;

	public CommandBody addPostfachAddressToBody(PostfachMail nachricht, VorgangWithEingang vorgang) {
		return addPostfachAddress(nachricht, createPostfachAddressForPostfachMail(vorgang));
	}

	private PostfachMail addPostfachAddress(PostfachMail nachricht, Map<String, Object> postfachAddress) {
		return nachricht.toBuilder().postfachAddress(postfachAddress).build();
	}

	private Map<String, Object> createPostfachAddressForPostfachMail(VorgangWithEingang vorgang) {
		Map<String, Object> postfachAddressForPostfachMail = new HashMap<>(mapper.mapPostfachAddressToMap(getPostfachAddress(vorgang)));
		postfachAddressForPostfachMail.put(SERVICEKONTO_TYPE_FIELD, getServiceKontoType(vorgang));
		return Collections.unmodifiableMap(postfachAddressForPostfachMail);
	}

	private PostfachAddress getPostfachAddress(VorgangWithEingang vorgang) {
		return vorgang.getHeader().getServiceKonto().getPostfachAddresses().get(0);
	}

	private String getServiceKontoType(VorgangWithEingang vorgang) {
		return vorgang.getHeader().getServiceKonto().getType();
	}

}