/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.bescheid;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

class DocumentServiceTest {

	@Mock
	private DocumentRemoteService remoteService;
	@Spy
	@InjectMocks
	private DocumentService service;

	@Nested
	class TestGetDocument {

		private final Document document = DocumentTestFactory.create();

		@BeforeEach
		void init() {
			when(remoteService.getDocument(DocumentTestFactory.ID)).thenReturn(document);
		}

		@Test
		void shouldCallRemoteService() {
			service.getDocument(DocumentTestFactory.ID);

			verify(remoteService).getDocument(DocumentTestFactory.ID);
		}

		@Test
		void shouldReturnResultFromRemoteService() {
			var result = service.getDocument(DocumentTestFactory.ID);

			assertThat(result).isEqualTo(document);
		}
	}
}
