/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.collaboration;

import org.springframework.test.web.servlet.ResultActions;
import org.springframework.test.web.servlet.result.JsonPathResultMatchers;
import org.springframework.test.web.servlet.result.MockMvcResultMatchers;
import org.springframework.web.util.UriComponentsBuilder;

import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
class CollaborationAssertions {

	private final boolean collectionModel;

	void assertHasFields(ResultActions response) throws Exception {
		response.andExpect(jsonPath("id").doesNotExist())
				.andExpect(jsonPath("vorgangId").doesNotExist())
				.andExpect(jsonPath("collaborationVorgangId").doesNotExist())
				.andExpect(jsonPath("titel").value(OrganisationsEinheitCollaborationTestFactory.TITEL))
				.andExpect(jsonPath("beschreibung").value(OrganisationsEinheitCollaborationTestFactory.BESCHREIBUNG))
				.andExpect(jsonPath("collaborationLevel").value(OrganisationsEinheitCollaborationTestFactory.COLLABORATION_LEVEL));
	}

	void assertHasZustaendigeStelleLink(ResultActions response, String controllerPath, String zustaendigeStelle) throws Exception {
		var expectedLink = UriComponentsBuilder
				.fromUriString("http://localhost")
				.path(controllerPath)
				.pathSegment(zustaendigeStelle)
				.build();

		response.andExpect(jsonPath("zustaendigeStelle").value(expectedLink.toString()));
	}

	private JsonPathResultMatchers jsonPath(String expression, Object... args) {
		return MockMvcResultMatchers.jsonPath(jsonPathPrefix() + expression, args);
	}

	private String jsonPathPrefix() {
		var prefix = "$.";
		if (collectionModel) {
			prefix += "content[0].";
		}
		return prefix;
	}
}
