/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common.errorhandling;

import org.springframework.security.access.AccessDeniedException;

import de.ozgcloud.alfa.common.GrpcUtil;
import io.grpc.Metadata;
import io.grpc.Status;
import io.grpc.StatusRuntimeException;

public class GrpcExceptionTestFactory {

	public static final String NOT_FOUND_DESCRIPTION = "Not Found Exception message";
	public static final String TECHNICAL_DESCRIPTION = "Technical Exception message";
	public static final String PERMISSION_DENIED_DESCRIPTION = "PermissionsDenied Exception message";
	public static final String PERMISSION_DENIED_CAUSE_MSG = "AccessDenied cause message";

	public static final String METADATA_ERROR_CODE_VALUE = "Error_Code";
	public static final String METADATA_EXCEPTION_ID_VALUE = "42";

	public static StatusRuntimeException createGrpcUnavailableStatusException(Metadata metadata) {
		return new StatusRuntimeException(buildUnavailableStatus(), metadata);
	}

	public static StatusRuntimeException createGrpcUnavailableStatusException() {
		return new StatusRuntimeException(buildUnavailableStatus());
	}

	public static Status buildUnavailableStatus() {
		return Status.UNAVAILABLE.withCause(new RuntimeException());
	}

	public static StatusRuntimeException createGrpcNotFoundStatusException(Metadata metadata) {
		return new StatusRuntimeException(buildNotFoundStatus(), metadata);
	}

	public static StatusRuntimeException createGrpcNotFoundStatusRuntimeException() {
		return new StatusRuntimeException(buildNotFoundStatus());
	}

	private static Status buildNotFoundStatus() {
		return Status.NOT_FOUND.withDescription(NOT_FOUND_DESCRIPTION).withCause(new RuntimeException());
	}

	public static StatusRuntimeException createGrpcInternalStatusException(Metadata metaData) {
		return new StatusRuntimeException(buildInternalStatus(), metaData);
	}

	public static StatusRuntimeException createGrpcInternalStatusException() {
		return new StatusRuntimeException(buildInternalStatus());
	}

	private static Status buildInternalStatus() {
		return Status.INTERNAL.withDescription(TECHNICAL_DESCRIPTION).withCause(new RuntimeException());
	}

	public static StatusRuntimeException createGrpcPermissionDeniedStatusException() {
		return new StatusRuntimeException(buildPermissionDeniedStatus());
	}

	public static Status buildPermissionDeniedStatus() {
		return Status.PERMISSION_DENIED.withDescription(PERMISSION_DENIED_DESCRIPTION)
				.withCause(new AccessDeniedException(PERMISSION_DENIED_CAUSE_MSG));
	}

	public static Metadata createMetaData() {
		Metadata data = new Metadata();
		data.put(GrpcUtil.keyOfString(GrpcExceptionController.KEY_ERROR_CODE), METADATA_ERROR_CODE_VALUE);
		data.put(GrpcUtil.keyOfString(GrpcExceptionController.KEY_EXCEPTION_ID), METADATA_EXCEPTION_ID_VALUE);
		return data;
	}

	public static Metadata createMetaDataWithSingleEntry(String key, String value) {
		Metadata data = new Metadata();
		data.put(GrpcUtil.keyOfString(key), value);
		return data;
	}
}