/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.postfach;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.Spy;

public class PostfachConfigMapperTest {

	@Spy
	private final PostfachConfigMapper mapper = Mappers.getMapper(PostfachConfigMapper.class);

	@Nested
	class TestToPostfachConfig {

		@Test
		void shouldMapReplyAllowed() {
			var postfachConfig = mapper.toPostfachConfig(GrpcPostfachTestFactory.create());

			assertThat(postfachConfig.isReplyAllowed()).isEqualTo(GrpcPostfachTestFactory.REPLY_ALLOWED);
		}

		@Test
		void shouldMapType() {
			var postfachConfig = mapper.toPostfachConfig(GrpcPostfachTestFactory.create());

			assertThat(postfachConfig.getType()).isEqualTo(GrpcPostfachTestFactory.TYPE);
		}
	}

	@Nested
	class TestToPostfachConfigGroup {

		@Test
		void shouldMapConfigured() {
			var postfachConfigGroup = mapper.toPostfachConfigGroup(GrpcGetPostfachConfigResponseTestFactory.create());

			assertThat(postfachConfigGroup.isConfigured()).isEqualTo(GrpcGetPostfachConfigResponseTestFactory.CONFIGURED);
		}

		@Test
		void shouldMapPostfachConfigs() {
			var expectedPostfachConfig = PostfachConfigTestFactory.create();
			doReturn(expectedPostfachConfig).when(mapper).toPostfachConfig(GrpcPostfachTestFactory.create());

			var postfachConfigGroup = mapper.toPostfachConfigGroup(GrpcGetPostfachConfigResponseTestFactory.create());

			assertThat(postfachConfigGroup.getPostfachConfigs()).containsOnly(expectedPostfachConfig);
		}
	}
}
