/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.vorgang;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Test;

class VorgangWithEingangTest {

	@Test
	void shouldGetOrganisationseinheitWhenSet() {
		VorgangWithEingang vorgang = VorgangWithEingangTestFactory.create();

		String organisationseinheitenID = vorgang.getOrganisationseinheitenID();

		assertThat(organisationseinheitenID).isEqualTo(ZustaendigeStelleTestFactory.ORGANISATIONSEINHEITEN_ID);
	}

	@Test
	void shouldNotGetOrganisationseinheitWithEingangUnset() {
		VorgangWithEingang vorgang = createVorgangWithNullEingang();

		String organisationseinheitenID = vorgang.getOrganisationseinheitenID();

		assertThat(organisationseinheitenID).isNull();
	}

	@Test
	void shouldNotGetOrganisationseinheitWithZustaendigeStelleUnset() {
		VorgangWithEingang vorgang = createVorgangWithNullZustaendigeStelle();

		String organisationseinheitenID = vorgang.getOrganisationseinheitenID();

		assertThat(organisationseinheitenID).isNull();
	}

	@Test
	void shouldNotGetOrganisationseinheitWithOrganisationseinheitUnset() {
		VorgangWithEingang vorgang = createVorgangWithNullOrganisationseinheit();

		String organisationseinheitenID = vorgang.getOrganisationseinheitenID();

		assertThat(organisationseinheitenID).isNull();
	}

	private VorgangWithEingang createVorgangWithNullEingang() {
		return createVorgangWithEingang(null);
	}

	private VorgangWithEingang createVorgangWithNullZustaendigeStelle() {
		Eingang eingang = EingangTestFactory.createBuilder().zustaendigeStelle(null).build();

		return createVorgangWithEingang(eingang);
	}

	private VorgangWithEingang createVorgangWithNullOrganisationseinheit() {
		ZustaendigeStelle zustaendigeStelle = ZustaendigeStelle.builder().organisationseinheitenId(null).build();
		Eingang eingang = EingangTestFactory.createBuilder().zustaendigeStelle(zustaendigeStelle).build();

		return createVorgangWithEingang(eingang);
	}

	private VorgangWithEingang createVorgangWithEingang(Eingang eingang) {
		return VorgangWithEingangTestFactory.createBuilder().eingang(eingang).build();
	}

}